# Data_mongo Service

The data_mongo service is intended to <UPDATE AND DEFINE PURPOSE HERE>


## Data_mongo is available at /data_mongo/
- Create a new data_mongo (POST /data_mongo/)
- Delete a data_mongo (DELETE /data_mongo/<id>)
- Update a data_mongo (PUT /data_mongo/<id>)
- Get a data_mongo by Id (GET /data_mongo/<ID>)
- Get a list of data_mongo by page (GET /data_mongo/?limit=25&offset=0) 
- Filter the list of data_mongo (GET /data_mongo/?name=myName)